import { CommonModule } from '@angular/common';
import { Component } from '@angular/core';

@Component({
  selector: 'app-accessibility-page',
  standalone: true,
  imports: [CommonModule],
  template: `<div class="ozg-prose prose prose-h1:text-4xl prose-h2:text-2xl">
    <h1>Erklärung zur Barrierefreiheit</h1>
    <p>
      Die Staatskanzlei des Ministerpräsidenten ist bemüht, ihre Anwendung im Einklang mit § 11 Absatz 1
      Landesbehindertengleichstellungsgesetz (LBGG) sowie den Anforderungen der Barrierefreiheit gemäß § 13 Absatz 3 LBGG
      barrierefrei zugänglich zu machen.
    </p>
    <p>
      Diese Erklärung zur Barrierefreiheit gilt für Unterseiten und Subdomains von
      <a href="https://kop.schleswig-holstein.de">https://kop.schleswig-holstein.de</a>
    </p>
    <h2>Stand der Vereinbarkeit mit den Anforderungen</h2>
    <p>Diese Website/mobile Anwendung ist teilweise mit § 13 Absatz 3 LBGG vereinbar.</p>
    <p>
      Die Anwendung befindet sich derzeit noch in der Entwicklung. An bestehenden und bekannten Barrieren wird gearbeitet, um eine
      Barrierefreiheit gemäß § 13 Absatz 3 LBGG gewährleisten zu können.
    </p>
    <h2>Allgemeiner Bereich</h2>
    <h3>Nicht barrierefreie Inhalte</h3>
    <p>Die nachstehend aufgeführten Inhalte sind unvereinbar mit § 13 Absatz 3 LBGG und somit nicht barrierefrei:</p>
    <ul>
      <li>Erläuterungen zu den Inhalten und der Navigation dieser Anwendung in leichter Sprache sind nicht vorhanden.</li>
      <li>
        Responsive Darstellung ist nicht vorhanden, weshalb Inhalte nur bedingt verlustfrei vergrößerbar sind oder umbrechen.
      </li>
      <li>Gliedernde Überschriften und Bereiche sind nicht umfassend vorhanden.</li>
      <li>Benutzerdefinierte Einstellungen (Farbauswahl und Schriftgröße) werden nicht umfänglich angewendet.</li>
      <li>Die Einstellungsmöglichkeiten im oberen Navigationsmenü können nicht per Tastatursteuerung erreicht werden.</li>
      <li>Die Vorschläge der Vorgangssuche sind nicht per Screenreader wahrnehmbar.</li>
      <li>Vereinzelt treten Texte mit zu geringem Kontrast zum Hintergrund auf.</li>
      <li>Vereinzelt ist der Tastaturfokus nur schwer wahrnehmbar. Bei Datumspickern ist keine Fokushervorhebung vorhanden.</li>
      <li>
        Es fehlen Statusmeldungen, die Screenreader-Nutzende über Änderungen der Suchergebnisse oder über Änderungen von Anträgen
        informieren.
      </li>
      <li>
        Der als PDF zur Verfügung gestellte Benutzerleitfaden, sowie die als PDF abgespeicherten Nachrichten der Anwendung
        entsprechen nicht dem PDF/UA-Standard.
      </li>
    </ul>
    <h2>Administrationsbereich</h2>
    <h3>Nicht barrierefreie Inhalte</h3>
    <p>Die nachstehend aufgeführten Inhalte sind unvereinbar mit § 13 Absatz 3 LBGG und somit nicht barrierefrei:</p>
    <ul>
      <li>Erläuterungen zu den Inhalten und der Navigation dieser Anwendung in leichter Sprache sind nicht vorhanden.</li>
      <li>
        Responsive Darstellung ist nicht vorhanden, weshalb Inhalte nur bedingt verlustfrei vergrößerbar sind oder umbrechen.
      </li>
      <li>Gliedernde Überschriften und Bereiche sind nicht umfassend vorhanden.</li>
      <li>Der Login ist nicht per Tastatursteuerung möglich.</li>
      <li>Der Tastaturfokus nur schwer wahrnehmbar.</li>
    </ul>
    <h2>Erstellung dieser Erklärung zur Barrierefreiheit</h2>
    <p>Diese Erklärung wurde am 15.07.2024 erstellt.</p>
    <p>
      Die Aussagen bezüglich der Vereinbarkeit mit den Barrierefreiheitsanforderungen in dieser Erklärung beruhen auf einem
      Prüfbericht von Dataport vom 08.04.2024 und einer Selbstbewertung.
    </p>
    <p>Die Erklärung wurde zuletzt am 15.07.2024 aktualisiert.</p>
    <h2>Feedback und Kontaktangaben</h2>
    <p>
      Sie möchten uns bestehende Barrieren mitteilen oder Informationen zur Umsetzung der Barrierefreiheit erfragen? Für Ihr
      Feedback sowie alle weiteren Informationen sprechen Sie unsere Verantwortlichen Kontaktpersonen unter
      <a href="mailto:digitalisierung@stk.landsh.de">digitalisierung&#64;stk.landsh.de</a> an.
    </p>
    <h2>Beschwerdeverfahren</h2>
    <p>
      Wenn auch nach Ihrem Feedback an den oben genannten Kontakt keine zufriedenstellende Lösung gefunden wurde, können Sie sich
      an die Beschwerdestelle des Landes Schleswig-Holstein gemäß Landesbehindertengleichstellungsgesetz (LBGG) wenden. Die
      Beschwerdestelle hat die Aufgabe, Konflikte zum Thema Barrierefreiheit zwischen Menschen mit Behinderungen und öffentlichen
      Stellen in Schleswig-Holstein zu lösen. Dabei geht es nicht darum, Gewinner oder Verlierer zu finden. Vielmehr ist es das
      Ziel, mit Hilfe der Beschwerdestelle gemeinsam und außergerichtlich eine Lösung für ein Problem zu finden. Das
      Beschwerdeverfahren ist kostenlos. Es muss kein Rechtsbeistand eingeschaltet werden.
    </p>
    <p>
      Auf der
      <a
        href="https://www.landtag.ltsh.de/beauftragte/beschwerdestelle-fuer-barrieren/"
        title="Sie verlassen die Seite"
        target="_blank"
        >Internetseite der Beschwerdestelle</a
      >
      finden Sie alle Informationen zum Beschwerdeverfahren. Dort können Sie nachlesen, wie ein Beschwerdeverfahren abläuft.
    </p>
    <p>Sie erreichen die Beschwerdestelle unter folgender Adresse:</p>
    <p>Beschwerdestelle nach dem Behindertengleichstellungsgesetz bei der Landesbeauftragten für Menschen mit Behinderung</p>
    <p>Büroanschrift: Karolinenweg 1, 24105 Kiel</p>
    <p>Postanschrift: Postfach 7121, 24171 Kiel</p>
    <p>Telefon: +49 431 988 1620</p>
    <p>E-Mail: <a href="mailto:bbit&#64;landtag.ltsh.de">bbit&#64;landtag.ltsh.de</a></p>
  </div>`,
})
export class AccessibilityPageComponent {}
