/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ExterneFachstelleResourceService } from '@alfa-client/externe-fachstelle-shared';
import { createEmptyStateResource, StateResource } from '@alfa-client/tech-shared';
import { ExterneFachstelleResource } from '@alfa-client/zustaendige-stelle-shared';
import { CommonModule } from '@angular/common';
import { Component, inject, Input, OnInit } from '@angular/core';
import { ResourceUri } from '@ngxp/rest';
import { Observable, of } from 'rxjs';
import { ExterneFachstelleListItemComponent } from './externe-fachstelle-list-item/externe-fachstelle-list-item.component';

@Component({
  selector: 'alfa-externe-fachstelle-list-item-container',
  standalone: true,
  imports: [CommonModule, ExterneFachstelleListItemComponent],
  providers: [ExterneFachstelleResourceService],
  templateUrl: './externe-fachstelle-list-item-container.component.html',
})
export class ExterneFachstelleListItemContainerComponent implements OnInit {
  private externeFachstelleResourceService: ExterneFachstelleResourceService = inject(ExterneFachstelleResourceService);

  @Input() externeFachstelleResourceUri: ResourceUri;

  externeFachstelleStateResource$: Observable<StateResource<ExterneFachstelleResource>> =
    of(createEmptyStateResource<ExterneFachstelleResource>());

  ngOnInit() {
    this.externeFachstelleStateResource$ = this.externeFachstelleResourceService.getExterneFachstelle(
      this.externeFachstelleResourceUri,
    );
  }
}
