/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { createStateResource, StateResource } from '@alfa-client/tech-shared';
import { createHintListResource } from 'libs/hint-shared/test/hint';
import { createEmptyListResource } from 'libs/tech-shared/test/resource';
import { HintListResource } from '../hint.model';
import { HintPartialState, initialState } from './hint.reducer';

import * as HintUtil from '../hint.util';
import * as HintSelectors from './hint.selectors';

describe('Hint Selectors', () => {
  let state: HintPartialState;

  const hintList: StateResource<HintListResource> = createStateResource(createHintListResource());

  beforeEach(() => {
    state = {
      HintState: {
        ...initialState,
        hintList,
      },
    };
  });

  describe('hasNoOrganisationsEinheitId', () => {
    const getHasUserNoOrganisationsEinheitIdSpy: jest.SpyInstance<boolean, [hintList: HintListResource]> = jest.spyOn(
      HintUtil,
      'hasUserNoOrganisationsEinheitIdHint',
    );

    it('should return stateResource with hint if exist', () => {
      getHasUserNoOrganisationsEinheitIdSpy.mockReturnValue(true);

      const result: boolean = HintSelectors.hasUserNoOrganisationsEinheitIdHint.projector(state.HintState);

      expect(result).toBeTruthy();
    });

    it('should return emptyStateResource if not exist', () => {
      getHasUserNoOrganisationsEinheitIdSpy.mockReturnValue(false);

      const result: boolean = HintSelectors.hasUserNoOrganisationsEinheitIdHint.projector(state.HintState);

      expect(result).toBeFalsy();
    });

    it('should return emptyStateResource if resource is null', () => {
      const result: boolean = HintSelectors.hasUserNoOrganisationsEinheitIdHint.projector({
        ...state.HintState,
        hintList: createEmptyListResource<HintListResource>(),
      });

      expect(result).toBeFalsy();
    });
  });
});
