/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { faker } from '@faker-js/faker';
import { toResource } from 'libs/tech-shared/test/resource';
import { times } from 'lodash-es';
import { HintListLinkRel } from '../src/lib/hint.linkrel';
import { Hint, HintListResource, HintResource } from '../src/lib/hint.model';

export function createHint(): Hint {
  return { code: faker.string.alphanumeric() };
}

export function createHintResource(linkRelations: string[] = []): HintResource {
  return toResource(createHint(), linkRelations);
}

export function createHintResources(linkRelations: string[] = []): HintResource[] {
  return times(10, () => toResource(createHintResource(), [...linkRelations]));
}

export function createHintListResource(linkRelations: string[] = []): HintListResource {
  return toResource({}, [...linkRelations], {
    [HintListLinkRel.HINT_LIST]: createHintResources([...linkRelations]),
  });
}

export function createHintListResourceWithResource(
  resources: HintResource[],
  linkRelations: string[] = [],
): HintListResource {
  return toResource({}, [...linkRelations], {
    [HintListLinkRel.HINT_LIST]: resources,
  });
}
