/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { Component, EventEmitter, Input, OnChanges, Output } from '@angular/core';
import { CommandResource } from '@alfa-client/command-shared';
import {
  KommentarListLinkRel,
  KommentarListResource,
  KommentarResource,
  KommentarService,
} from '@alfa-client/kommentar-shared';
import {
  createEmptyStateResource,
  getEmbeddedResources,
  StateResource,
} from '@alfa-client/tech-shared';
import { isNil } from 'lodash-es';
import { Observable, of } from 'rxjs';
import { KommentarFormService } from './kommentar.formservice';
import { BinaryFileListLinkRel, BinaryFileResource } from '@alfa-client/binary-file-shared';
import { map } from 'rxjs/operators';

@Component({
  selector: 'alfa-kommentar-form',
  templateUrl: './kommentar-form.component.html',
  styleUrls: ['./kommentar-form.component.scss'],
  providers: [KommentarFormService],
})
export class KommentarFormComponent implements OnChanges {
  @Input() kommentar: KommentarResource;
  @Input() kommentarListStateResource: StateResource<KommentarListResource>;

  @Output() cancel: EventEmitter<void> = new EventEmitter();

  submitInProgress$: Observable<StateResource<CommandResource>> = of(
    createEmptyStateResource<CommandResource>(),
  );

  readonly formServiceClass = KommentarFormService;
  readonly kommentarListLinkRel = KommentarListLinkRel;

  attachments$: Observable<BinaryFileResource[]> = of([]);

  constructor(
    public formService: KommentarFormService,
    public kommentarService: KommentarService,
  ) {}

  ngOnChanges(): void {
    if (!isNil(this.kommentar)) {
      this.patch();
      this.updateAttachments();
    }
  }

  private updateAttachments() {
    this.attachments$ = this.kommentarService
      .getAttachments(this.kommentar)
      .pipe(
        map((stateResource) =>
          getEmbeddedResources<BinaryFileResource>(stateResource, BinaryFileListLinkRel.FILE_LIST),
        ),
      );
  }

  patch(): void {
    this.formService.patch(this.kommentar);
  }

  submit(): void {
    this.submitInProgress$ = <Observable<StateResource<CommandResource>>>this.formService.submit();
  }
}
