/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { createStateResource, StateResource } from '@alfa-client/tech-shared';
import { initialPostfachState, PostfachPartialState } from './postfach.reducer';

import { BinaryFileListResource } from '@alfa-client/binary-file-shared';
import { createBinaryFileListResource } from 'libs/binary-file-shared/test/binary-file';
import * as PostfachSelectors from './postfach.selectors';

describe('Postfach Selectors', () => {
  let state: PostfachPartialState;

  const isDownloadPdfInProgress: boolean = true;
  const attachmentList: StateResource<BinaryFileListResource> = createStateResource(
    createBinaryFileListResource(),
  );

  beforeEach(() => {
    state = {
      PostfachState: {
        ...initialPostfachState,
        isDownloadPdfInProgress,
        attachmentList,
      },
    };
  });

  it('should return isDownloadPdfInProgress', () => {
    expect(PostfachSelectors.isDownloadPdfInProgress.projector(state.PostfachState)).toBe(
      isDownloadPdfInProgress,
    );
  });

  it('should return attachmentList', () => {
    expect(PostfachSelectors.attachmentList.projector(state.PostfachState)).toBe(attachmentList);
  });
});
