/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { createEmptyStateResource } from '@alfa-client/tech-shared';
import { createSuccessfullyDoneCommandStateResource } from '../../../../../command-shared/test/command';
import {
  createDialogCancelResult,
  createDialogResult,
  isDialogCanceled,
  isDialogSuccessfullyCompleted,
  OzgcloudDialogCommandResult,
} from './ozgcloud-dialog.result';

describe('ozgcloud-dialog.result', () => {
  describe('isDialogCanceled', () => {
    it('should return true', () => {
      const isDialogCancelled: boolean = isDialogCanceled({ stateResource: createEmptyStateResource() });

      expect(isDialogCancelled).toBeTruthy();
    });

    it('should return false for null result', () => {
      const isDialogCancelled: boolean = isDialogCanceled(null);

      expect(isDialogCancelled).toBeFalsy();
    });

    it('should return false for null state resource', () => {
      const isDialogCancelled: boolean = isDialogCanceled({ stateResource: null });

      expect(isDialogCancelled).toBeFalsy();
    });

    it('should return false for non empty state resource', () => {
      const isDialogCancelled: boolean = isDialogCanceled({ stateResource: createSuccessfullyDoneCommandStateResource() });

      expect(isDialogCancelled).toBeFalsy();
    });
  });

  describe('isDialogSuccessfullyCompleted', () => {
    it('should return true', () => {
      const isSuccessfullyCompleted: boolean = isDialogSuccessfullyCompleted({
        stateResource: createSuccessfullyDoneCommandStateResource(),
      });
      expect(isSuccessfullyCompleted).toBeTruthy();
    });

    it('should return false for null result', () => {
      const isSuccessfullyCompleted: boolean = isDialogSuccessfullyCompleted(null);

      expect(isSuccessfullyCompleted).toBeFalsy();
    });

    it('should return false for null state resource', () => {
      const isSuccessfullyCompleted: boolean = isDialogSuccessfullyCompleted({ stateResource: null });

      expect(isSuccessfullyCompleted).toBeFalsy();
    });

    it('should return false for empty state resource', () => {
      const isSuccessfullyCompleted: boolean = isDialogSuccessfullyCompleted({ stateResource: createEmptyStateResource() });

      expect(isSuccessfullyCompleted).toBeFalsy();
    });
  });

  describe('createDialogCancelResult', () => {
    it('should create', () => {
      const dialogResult: OzgcloudDialogCommandResult = createDialogCancelResult();

      expect(dialogResult.stateResource).toEqual(createEmptyStateResource());
    });
  });

  describe('createDialogResult', () => {
    it('should create', () => {
      const stateResource = createSuccessfullyDoneCommandStateResource();

      const dialogCommandResult: OzgcloudDialogCommandResult = createDialogResult(stateResource);

      expect(dialogCommandResult.stateResource).toBe(stateResource);
    });
  });
});
