/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { mock } from '@alfa-client/test-utils';
import { UserProfileService } from '@alfa-client/user-profile-shared';
import { DummyLinkRel } from 'libs/tech-shared/test/dummy';
import { createDummyResource } from 'libs/tech-shared/test/resource';
import { MockComponent } from 'ng-mocks';
import { LinkWithUserNameTooltipContainerComponent } from './link-with-user-name-tooltip-container.component';
import { LinkWithUserNameTooltipComponent } from './link-with-user-name-tooltip/link-with-user-name-tooltip.component';

describe('LinkWithUserNameTooltipContainerComponent', () => {
  let component: LinkWithUserNameTooltipContainerComponent;
  let fixture: ComponentFixture<LinkWithUserNameTooltipContainerComponent>;

  const userProfileService = mock(UserProfileService);

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        LinkWithUserNameTooltipContainerComponent,
        MockComponent(LinkWithUserNameTooltipComponent),
      ],
      providers: [
        {
          provide: UserProfileService,
          useValue: userProfileService,
        },
      ],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(LinkWithUserNameTooltipContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('ngOnInit', () => {
    describe('user profile service', () => {
      beforeEach(() => {
        userProfileService.getAssignedUserProfile.mockClear();
      });

      it('should call if link is present', () => {
        component.resource = createDummyResource([DummyLinkRel.DUMMY]);
        component.linkRel = DummyLinkRel.DUMMY;

        component.ngOnInit();

        expect(userProfileService.getAssignedUserProfile).toHaveBeenCalledWith(
          component.resource,
          DummyLinkRel.DUMMY,
        );
      });

      it('should not call if link is not present', () => {
        component.resource = createDummyResource();

        component.ngOnInit();

        expect(userProfileService.getAssignedUserProfile).not.toHaveBeenCalled();
      });
    });
  });
});
