/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { mock } from '@alfa-client/test-utils';
import { EventEmitter } from '@angular/core';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { VorgangDetailBescheidenStepButtonComponent } from './vorgang-detail-bescheiden-step-button.component';

describe('VorgangDetailBescheidenStepButtonComponent', () => {
  let component: VorgangDetailBescheidenStepButtonComponent;
  let fixture: ComponentFixture<VorgangDetailBescheidenStepButtonComponent>;

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [VorgangDetailBescheidenStepButtonComponent],
    }).compileComponents();

    fixture = TestBed.createComponent(VorgangDetailBescheidenStepButtonComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('isActive', () => {
    it('return true if step equals activeStep', () => {
      component.step = 2;
      component.activeStep = 2;

      expect(component.isActive()).toBeTruthy();
    });

    it('return false if step not equals activeStep', () => {
      component.step = 1;
      component.activeStep = 2;

      expect(component.isActive()).toBeFalsy();
    });
  });

  describe('isPrevious', () => {
    it('return true if step is less than activeStep', () => {
      component.step = 1;
      component.activeStep = 2;

      expect(component.isPrevious()).toBeTruthy();
    });

    it('return false if step equals activeStep', () => {
      component.step = 2;
      component.activeStep = 2;

      expect(component.isPrevious()).toBeFalsy();
    });

    it('return false if step is greater than activeStep', () => {
      component.step = 3;
      component.activeStep = 2;

      expect(component.isPrevious()).toBeFalsy();
    });
  });

  describe('isNext', () => {
    it('return false if step is less than activeStep', () => {
      component.step = 1;
      component.activeStep = 2;

      expect(component.isNext()).toBeFalsy();
    });

    it('return false if step equals activeStep', () => {
      component.step = 2;
      component.activeStep = 2;

      expect(component.isNext()).toBeFalsy();
    });

    it('return true if step is greater than activeStep', () => {
      component.step = 3;
      component.activeStep = 2;

      expect(component.isNext()).toBeTruthy();
    });
  });

  describe('clickHandler', () => {
    const isPreviousMock = jest.fn();
    beforeEach(() => {
      component.isPrevious = isPreviousMock;
      component.activeStepChange = <any>mock(EventEmitter);
    });

    it('should emit step', () => {
      isPreviousMock.mockReturnValue(true);

      component.clickHandler(1);

      expect(component.activeStepChange.emit).toHaveBeenCalledWith(1);
    });

    it('should not emit step', () => {
      isPreviousMock.mockReturnValue(false);

      component.clickHandler(1);

      expect(component.activeStepChange.emit).not.toHaveBeenCalled();
    });
  });
});
