/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BescheidLinkRel, BescheidService } from '@alfa-client/bescheid-shared';
import { CommandLinkRel } from '@alfa-client/command-shared';
import {
  createEmptyStateResource,
  createStateResource,
  HasLinkPipe,
} from '@alfa-client/tech-shared';
import {
  dispatchEventFromFixture,
  existsAsHtmlElement,
  Mock,
  mock,
  notExistsAsHtmlElement,
} from '@alfa-client/test-utils';
import { OzgcloudButtonWithSpinnerComponent } from '@alfa-client/ui';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import {
  BescheidGenerateIconComponent,
  ButtonCardComponent,
  SpinnerIconComponent,
} from '@ods/system';
import { createBescheidResource } from 'libs/bescheid-shared/src/test/bescheid';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import {
  createCommandErrorStateResource,
  createCommandStateResource,
} from '../../../../../../../../../command-shared/test/command';
import { BescheidenFormService } from '../../../../bescheiden.formservice';
import { VorgangDetailBescheidenBescheidAutomatischErstellenComponent } from './vorgang-detail-bescheiden-bescheid-automatisch-erstellen.component';

describe('VorgangDetailBescheidenBescheidAutomatischErstellenComponent', () => {
  let component: VorgangDetailBescheidenBescheidAutomatischErstellenComponent;
  let fixture: ComponentFixture<VorgangDetailBescheidenBescheidAutomatischErstellenComponent>;

  const createBescheidDocumentButton: string = getDataTestIdOf('create-bescheid-document-button');

  let bescheidService: Mock<BescheidService>;
  let formService: Mock<BescheidenFormService>;

  beforeEach(async () => {
    bescheidService = mock(BescheidService);
    formService = mock(BescheidenFormService);

    await TestBed.configureTestingModule({
      imports: [HasLinkPipe],
      declarations: [
        VorgangDetailBescheidenBescheidAutomatischErstellenComponent,
        MockComponent(OzgcloudButtonWithSpinnerComponent),
        MockComponent(ButtonCardComponent),
        MockComponent(SpinnerIconComponent),
        MockComponent(BescheidGenerateIconComponent),
      ],
      providers: [
        {
          provide: BescheidService,
          useValue: bescheidService,
        },
        {
          provide: BescheidenFormService,
          useValue: formService,
        },
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(VorgangDetailBescheidenBescheidAutomatischErstellenComponent);
    component = fixture.componentInstance;
    component.bescheidDraftStateResource = createStateResource(createBescheidResource());
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('create bescheid document button', () => {
    beforeEach(() => {
      component.bescheidDraftStateResource = createStateResource(
        createBescheidResource([BescheidLinkRel.CREATE_DOCUMENT]),
      );

      fixture.detectChanges();
    });
    it('should call bescheid service on click', () => {
      dispatchEventFromFixture(fixture, createBescheidDocumentButton, 'click');

      expect(bescheidService.createBescheidDocument).toHaveBeenCalled();
    });

    it('should be hidden if link is NOT present', () => {
      component.bescheidDraftStateResource = createStateResource(createBescheidResource());

      fixture.detectChanges();

      notExistsAsHtmlElement(fixture, createBescheidDocumentButton);
    });

    it('should be visible if link is present', () => {
      component.bescheidDraftStateResource = createStateResource(
        createBescheidResource([BescheidLinkRel.CREATE_DOCUMENT]),
      );
      fixture.detectChanges();

      existsAsHtmlElement(fixture, createBescheidDocumentButton);
    });

    it('should clear nachricht', () => {
      bescheidService.createBescheidDocument.mockReturnValue(
        of(createCommandStateResource([CommandLinkRel.EFFECTED_RESOURCE])),
      );

      component.createBescheidDocument();

      component.createBescheidDocumentInProgress$.subscribe();
      expect(formService.clearNachricht).toHaveBeenCalled();
    });

    it('should not clear nachricht when loading', () => {
      bescheidService.createBescheidDocument.mockReturnValue(of(createEmptyStateResource(true)));

      component.createBescheidDocument();

      component.createBescheidDocumentInProgress$.subscribe();
      expect(formService.clearNachricht).not.toHaveBeenCalled();
    });

    it('should not clear nachricht when error', () => {
      bescheidService.createBescheidDocument.mockReturnValue(of(createCommandErrorStateResource()));

      component.createBescheidDocument();

      component.createBescheidDocumentInProgress$.subscribe();
      expect(formService.clearNachricht).not.toHaveBeenCalled();
    });
  });
});
