/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.bescheid;

import java.util.Optional;
import java.util.stream.Stream;

import org.apache.commons.collections.CollectionUtils;
import org.springframework.stereotype.Service;

import lombok.RequiredArgsConstructor;

@Service
@RequiredArgsConstructor
public class BescheidService {

	private final BescheidRemoteService remoteService;
	private final BescheidByBeschiedenAmComparator comparator;

	public Optional<Bescheid> getBescheidDraft(String vorgangId) {
		return remoteService.getBescheidDraft(vorgangId);
	}

	public Stream<Bescheid> findByVorgangId(String vorgangId) {
		return remoteService.findByVorgangId(vorgangId);
	}

	public Stream<Bescheid> findByVorgangIdSorted(String vorgangId) {
		return sortBescheids(remoteService.findByVorgangId(vorgangId));
	}

	Stream<Bescheid> sortBescheids(Stream<Bescheid> bescheids) {
		return bescheids.sorted(comparator.reversed());
	}

	public boolean canCreateBescheidDocumentAutomatically() {
		return remoteService.canCreateBescheidDocument();
	}

	public boolean existsBescheid(String vorgangId) {
		var bescheide = remoteService.findByVorgangId(vorgangId).toList();

		return CollectionUtils.isNotEmpty(bescheide);
	}
}
