/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.loeschanforderung;

import java.util.Map;

import org.apache.commons.collections.MapUtils;
import org.springframework.stereotype.Component;

import de.ozgcloud.alfa.common.attacheditem.VorgangAttachedItem;
import de.ozgcloud.alfa.common.command.Command;
import de.ozgcloud.alfa.common.command.CommandBodyMapper;
import de.ozgcloud.alfa.common.user.UserId;
import de.ozgcloud.alfa.vorgang.Vorgang.VorgangStatus;

@Component
class LoeschAnforderungMapper {

	public LoeschAnforderung fromVorgangAttachedItem(VorgangAttachedItem vorgangAttachedItem) {
		var item = vorgangAttachedItem.getItem();
		return LoeschAnforderung.builder()
				.id(vorgangAttachedItem.getId())
				.vorgangId(vorgangAttachedItem.getVorgangId())
				.requestedBy(getRequestedBy(item))
				.prevStatus(getPrevState(item))
				.build();
	}

	public LoeschAnforderung fromCommand(Command command) {
		var item = getItem(command);
		return LoeschAnforderung.builder()
				.id(command.getRelationId())
				.vorgangId(command.getVorgangId())
				.requestedBy(getRequestedBy(item))
				.prevStatus(getPrevState(item))
				.build();
	}

	@SuppressWarnings("unchecked")
	private Map<String, Object> getItem(Command command) {
		return MapUtils.getMap(command.getBody(), CommandBodyMapper.ITEM_PROPERTY);
	}

	private UserId getRequestedBy(Map<String, ?> item) {
		return UserId.from(MapUtils.getString(item, LoeschAnforderung.REQUESTED_BY_FIELD));
	}

	private VorgangStatus getPrevState(Map<String, ?> item) {
		return VorgangStatus.valueOf(MapUtils.getString(item, LoeschAnforderung.PREV_STATUS_FIELD));
	}
}
