/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.postfach;

import static de.ozgcloud.alfa.common.ValidationMessageCodes.*;

import java.time.ZonedDateTime;
import java.util.List;
import java.util.Map;

import jakarta.validation.constraints.NotEmpty;
import jakarta.validation.constraints.Size;

import com.fasterxml.jackson.annotation.JsonIgnore;

import de.ozgcloud.alfa.common.LinkedResource;
import de.ozgcloud.alfa.common.binaryfile.BinaryFileController;
import de.ozgcloud.alfa.common.binaryfile.FileId;
import de.ozgcloud.alfa.common.command.CommandBody;
import de.ozgcloud.alfa.common.user.UserId;
import lombok.AccessLevel;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Singular;
import lombok.ToString;

@Builder(toBuilder = true)
@Getter
@ToString
@NoArgsConstructor(access = AccessLevel.PRIVATE)
@AllArgsConstructor(access = AccessLevel.PUBLIC)
public class PostfachMail implements CommandBody {

	public static final String POSTFACH_ADDRESS_FIELD = "postfachAddress";

	enum Direction {
		IN, OUT
	}

	@JsonIgnore
	private String id;
	@JsonIgnore
	private Map<String, Object> postfachAddress;
	@JsonIgnore
	private String vorgangId;

	private ZonedDateTime createdAt;
	@JsonIgnore
	private UserId createdBy;

	private ZonedDateTime sentAt;
	private Boolean sentSuccessful;
	private String messageCode;

	private Direction direction;
	private ReplyOption replyOption;

	@NotEmpty(message = FIELD_IS_EMPTY)
	@Size(max = 70, message = FIELD_MAX_SIZE)
	private String subject;

	@NotEmpty(message = FIELD_IS_EMPTY)
	private String mailBody;

	@LinkedResource(controllerClass = BinaryFileController.class)
	@Singular
	private List<FileId> attachments;
}