/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.vorgang;

import java.time.LocalDate;
import java.util.List;

import org.mapstruct.CollectionMappingStrategy;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.ReportingPolicy;

import de.ozgcloud.alfa.common.clientattribute.ClientAttribute;
import de.ozgcloud.alfa.common.clientattribute.ClientAttributeUtils;
import de.ozgcloud.alfa.common.user.UserIdMapper;
import de.ozgcloud.vorgang.grpc.clientAttribute.GrpcClientAttribute;
import de.ozgcloud.vorgang.grpc.clientAttribute.GrpcClientAttributeValue;
import de.ozgcloud.vorgang.vorgang.GrpcVorgangHeader;

@Mapper(uses = UserIdMapper.class, unmappedTargetPolicy = ReportingPolicy.WARN, collectionMappingStrategy = CollectionMappingStrategy.ADDER_PREFERRED, imports = ClientAttribute.class)
interface VorgangHeaderMapper {

	@Mapping(target = "nextFrist", source = "clientAttributesList")
	@Mapping(target = "antragBewilligt", source = "clientAttributesList")
	@Mapping(target = "hasPostfachNachricht", expression = "java(mapBoolClientAttribute(vorgangHeader.getClientAttributesList(), ClientAttribute.HAS_POSTFACH_NACHRICHT))")
	@Mapping(target = "hasNewPostfachNachricht", expression = "java(mapBoolClientAttribute(vorgangHeader.getClientAttributesList(), ClientAttribute.HAS_NEW_POSTFACH_NACHRICHT))")
	VorgangHeader toVorgangHeader(GrpcVorgangHeader vorgangHeader);

	default LocalDate mapNextFrist(List<GrpcClientAttribute> clientAttributes) {
		return ClientAttributeUtils.findGrpcValue(ClientAttribute.WIEDERVORLAGE_NEXT_FRIST, clientAttributes)
				.map(GrpcClientAttributeValue::getStringValue)
				.map(LocalDate::parse).orElse(null);
	}

	default boolean mapBoolClientAttribute(List<GrpcClientAttribute> grpcClientAttributes, ClientAttribute clientAttribute) {
		return ClientAttributeUtils.findGrpcValue(clientAttribute, grpcClientAttributes)
				.map(GrpcClientAttributeValue::getBoolValue)
				.orElse(false);
	}

	default Boolean mapAntragBewilligt(List<GrpcClientAttribute> grpcClientAttributes) {
		return ClientAttributeUtils.findGrpcValue(ClientAttribute.ANTRAG_BEWILLIGT, grpcClientAttributes)
				.map(GrpcClientAttributeValue::getBoolValue)
				.orElse(null);
	}

}
