/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.wiedervorlage;

import static de.ozgcloud.alfa.common.ValidationMessageCodes.*;

import java.time.LocalDate;
import java.time.ZonedDateTime;
import java.util.List;

import jakarta.validation.constraints.FutureOrPresent;
import jakarta.validation.constraints.NotNull;
import jakarta.validation.constraints.Size;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonProperty.Access;

import de.ozgcloud.alfa.common.LinkedResource;
import de.ozgcloud.alfa.common.LinkedUserProfileResource;
import de.ozgcloud.alfa.common.binaryfile.BinaryFileController;
import de.ozgcloud.alfa.common.binaryfile.FileId;
import de.ozgcloud.alfa.common.command.CommandBody;
import lombok.AccessLevel;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Singular;
import lombok.ToString;

@Getter
@Builder(toBuilder = true)
@NoArgsConstructor(access = AccessLevel.PRIVATE)
@AllArgsConstructor(access = AccessLevel.PACKAGE)
@ToString
public class Wiedervorlage implements CommandBody {

	public static final String DONE_FIELD = "done";

	@JsonIgnore
	private String id;

	@JsonIgnore
	private String vorgangId;
	@JsonIgnore
	private long version;

	@JsonProperty(access = Access.READ_ONLY)
	private boolean done;

	@JsonIgnore
	@LinkedUserProfileResource
	private String createdBy;
	@JsonProperty(access = Access.READ_ONLY)
	private ZonedDateTime createdAt;

	@NotNull(message = FIELD_IS_EMPTY)
	@Size(min = 3, max = 40, message = FIELD_SIZE)
	private String betreff;
	private String beschreibung;

	@NotNull(message = FIELD_IS_EMPTY)
	@FutureOrPresent(message = FIELD_DATE_PAST)
	private LocalDate frist;

	@LinkedResource(controllerClass = BinaryFileController.class)
	@Singular
	private List<FileId> attachments;
}