/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.bescheid;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.*;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.*;

import java.util.List;
import java.util.stream.Stream;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.springframework.hateoas.CollectionModel;
import org.springframework.hateoas.EntityModel;
import org.springframework.test.web.servlet.MockMvc;
import org.springframework.test.web.servlet.ResultActions;
import org.springframework.test.web.servlet.setup.MockMvcBuilders;

import de.ozgcloud.alfa.bescheid.BescheidController.BescheidByVorgangController;
import de.ozgcloud.alfa.vorgang.VorgangHeaderTestFactory;
import lombok.SneakyThrows;

class BescheidByVorgangControllerTest {

	@InjectMocks
	private BescheidByVorgangController controller;

	@Mock
	private BescheidService service;

	@Mock
	private BescheidModelAssembler modelAssembler;

	private MockMvc mockMvc;

	@BeforeEach
	void initMockMvc() {
		mockMvc = MockMvcBuilders.standaloneSetup(controller).build();
	}

	@Nested
	class TestGetAll {
		private final Bescheid bescheid = BescheidTestFactory.create();

		@BeforeEach
		void setUpMock() {
			when(service.findByVorgangIdSorted(VorgangHeaderTestFactory.ID)).thenReturn(Stream.of(bescheid));
		}

		@Test
		@SneakyThrows
		void shouldReturnStatusOk() {
			var result = callEndpoint();

			result.andExpect(status().isOk());
		}

		@Test
		@SneakyThrows
		void shouldCallService() {
			callEndpoint();

			verify(service).findByVorgangIdSorted(VorgangHeaderTestFactory.ID);
		}

		@Test
		@SneakyThrows
		void shouldCallModelAssembler() {
			callEndpoint();

			verify(modelAssembler).toCollectionModel(List.of(bescheid));
		}

		@Test
		@SneakyThrows
		void shouldReturnCollectionModel() {
			CollectionModel<EntityModel<Bescheid>> model = CollectionModel.empty();
			when(modelAssembler.toCollectionModel(List.of(bescheid))).thenReturn(model);

			var result = callEndpoint();

			assertThat(result.andReturn().getResponse().getContentAsString()).isEqualTo("{\"links\":[],\"content\":[]}");
		}

		private ResultActions callEndpoint() throws Exception {
			return mockMvc.perform(get(BescheidByVorgangController.BESCHEID_BY_VORGANG_PATH + "/" + VorgangHeaderTestFactory.ID + "/bescheids"));
		}
	}
}
