/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.kommentar;

import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.*;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.springframework.test.web.servlet.MockMvc;
import org.springframework.test.web.servlet.ResultActions;
import org.springframework.test.web.servlet.setup.MockMvcBuilders;

import com.google.common.collect.Lists;

import de.ozgcloud.alfa.common.binaryfile.BinaryFileController;
import de.ozgcloud.alfa.common.binaryfile.BinaryFileTestFactory;

class KommentarControllerTest {

	private final String PATH = KommentarController.KOMMENTAR_PATH + "/{id}";

	@InjectMocks
	private KommentarController controller;

	@Mock
	private KommentarService service;

	@Mock
	private KommentarModelAssembler modelAssembler;

	@Mock
	private BinaryFileController binaryFileService;

	private MockMvc mockMvc;

	@BeforeEach
	void initTest() {
		mockMvc = MockMvcBuilders.standaloneSetup(controller).build();
	}

	@Nested
	class TestGetById {

		private Kommentar kommentar = KommentarTestFactory.create();

		@BeforeEach
		void mockService() {
			when(service.getById(any())).thenReturn(kommentar);
		}

		@Test
		void shouldReturnValue() throws Exception {
			ResultActions callEndpoint = callEndpoint();

			callEndpoint.andExpect(status().isOk());
		}

		@Test
		void shouldCallService() throws Exception {
			callEndpoint();

			verify(service).getById(KommentarTestFactory.ID);
		}

		@Test
		void shouldCallModelAssembler() throws Exception {
			callEndpoint();

			verify(modelAssembler).toModel(kommentar);
		}

		private ResultActions callEndpoint() throws Exception {
			return mockMvc.perform(get(PATH, KommentarTestFactory.ID));
		}
	}

	@Nested
	@DisplayName("GetKommentarAttachments")
	class TestGetKommentarAttachments {

		@Test
		void shouldGetAttachments() throws Exception {
			when(service.getById(anyString())).thenReturn(KommentarTestFactory.create());

			mockMvc.perform(get(PATH + "/attachments", KommentarTestFactory.ID));

			verify(service).getById(KommentarTestFactory.ID);
			verify(binaryFileService).getFiles(Lists.newArrayList(BinaryFileTestFactory.FILE_ID));
		}

	}
}